@@ -5,9 +5,12 @@ __all__ = []
 import logging
 
 from .catalogs import Catalog
+from .webservices import CallIper
 
 logger = logging.getLogger(__name__)
 
 #  TODO list and give access to whole services and their beta/alpha / pre-prod instances if existing
 
-oidb = Catalog("oidb")
+oidb_catalog = Catalog("oidb")
+
+calliper = CallIper()
